aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/search.php
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2015-07-23 10:20:10 +0200
committerMarc Alexander <admin@m-a-styles.de>2015-07-23 10:20:10 +0200
commitfb6afde2985f71a5bf4280e07c8c556a51a82eb6 (patch)
treef792f79e59f77dd65cbabb1633155d73403bc8f3 /phpBB/search.php
parente1cbe735380d98f2b87f4243317fd55cbc0439af (diff)
parent3e8af1cf335caf1daad477131458cb6ef5aa1a0a (diff)
downloadforums-fb6afde2985f71a5bf4280e07c8c556a51a82eb6.tar
forums-fb6afde2985f71a5bf4280e07c8c556a51a82eb6.tar.gz
forums-fb6afde2985f71a5bf4280e07c8c556a51a82eb6.tar.bz2
forums-fb6afde2985f71a5bf4280e07c8c556a51a82eb6.tar.xz
forums-fb6afde2985f71a5bf4280e07c8c556a51a82eb6.zip
Merge branch '3.1.x'
Diffstat (limited to 'phpBB/search.php')
-rw-r--r--phpBB/search.php23
1 files changed, 17 insertions, 6 deletions
diff --git a/phpBB/search.php b/phpBB/search.php
index 6bdac290d6..a211b113c0 100644
--- a/phpBB/search.php
+++ b/phpBB/search.php
@@ -1170,14 +1170,25 @@ if ($keywords || $author || $author_id || $search_id || $submit)
* Modify the title and/or load data for the search results page
*
* @event core.search_results_modify_search_title
* @var int author_id ID of the author to search by
* @var string l_search_title The title of the search page
* @var string search_id Predefined search type name
* @var string show_results Search results output mode - topics or posts
* @var int start The starting id of the results
* @since 3.1.0-RC4
+ * @changed 3.1.6-RC1 Added total_match_count and keywords
*/
- $vars = array('author_id', 'l_search_title', 'search_id', 'show_results', 'start');
+ $vars = array(
+ 'author_id',
+ 'l_search_title',
+ 'search_id',
+ 'show_results',
+ 'start',
+ 'total_match_count',
+ 'keywords',
+ );
extract($phpbb_dispatcher->trigger_event('core.search_results_modify_search_title', compact($vars)));
page_header(($l_search_title) ? $l_search_title : $user->lang['SEARCH']);
@@ -1170,14 +1170,25 @@ if ($keywords || $author || $author_id || $search_id || $submit)
*
* @event core.search_results_modify_search_title
- * @var int author_id ID of the author to search by
- * @var string l_search_title The title of the search page
- * @var string search_id Predefined search type name
- * @var string show_results Search results output mode - topics or posts
- * @var int start The starting id of the results
+ * @var int author_id ID of the author to search by
+ * @var string l_search_title The title of the search page
+ * @var string search_id Predefined search type name
+ * @var string show_results Search results output mode - topics or posts
+ * @var int start The starting id of the results
+ * @var int total_match_count The count of search results
+ * @var string keywords The search keywords
* @since 3.1.0-RC4